Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(389)

Unified Diff: Source/core/dom/LayoutTreeBuilder.cpp

Issue 977113003: Rename renderer() to layoutObject(). (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/dom/LayoutTreeBuilder.h ('k') | Source/core/dom/Node.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/dom/LayoutTreeBuilder.cpp
diff --git a/Source/core/dom/LayoutTreeBuilder.cpp b/Source/core/dom/LayoutTreeBuilder.cpp
index b4c6967db2c974fa5aee117cac00c8c022f744cb..a2acde0a5b217a31c64fcd3c01b87dbc50212f01 100644
--- a/Source/core/dom/LayoutTreeBuilder.cpp
+++ b/Source/core/dom/LayoutTreeBuilder.cpp
@@ -49,15 +49,15 @@ LayoutTreeBuilderForElement::LayoutTreeBuilderForElement(Element& element, Layou
{
if (element.isFirstLetterPseudoElement()) {
if (LayoutObject* nextRenderer = FirstLetterPseudoElement::firstLetterTextRenderer(element))
- m_renderingParent = nextRenderer->parent();
+ m_layoutObjectParent = nextRenderer->parent();
} else if (ContainerNode* containerNode = NodeRenderingTraversal::parent(element)) {
- m_renderingParent = containerNode->renderer();
+ m_layoutObjectParent = containerNode->layoutObject();
}
}
LayoutObject* LayoutTreeBuilderForElement::nextRenderer() const
{
- ASSERT(m_renderingParent);
+ ASSERT(m_layoutObjectParent);
if (m_node->isInTopLayer())
return NodeRenderingTraversal::nextInTopLayer(*m_node);
@@ -85,13 +85,13 @@ LayoutObject* LayoutTreeBuilderForElement::parentRenderer() const
bool LayoutTreeBuilderForElement::shouldCreateRenderer() const
{
- if (!m_renderingParent)
+ if (!m_layoutObjectParent)
return false;
// FIXME: Should the following be in SVGElement::layoutObjectIsNeeded()?
if (m_node->isSVGElement()) {
// SVG elements only render when inside <svg>, or if the element is an <svg> itself.
- if (!isSVGSVGElement(*m_node) && (!m_renderingParent->node() || !m_renderingParent->node()->isSVGElement()))
+ if (!isSVGSVGElement(*m_node) && (!m_layoutObjectParent->node() || !m_layoutObjectParent->node()->isSVGElement()))
return false;
if (!toSVGElement(m_node)->isValid())
return false;
@@ -134,7 +134,7 @@ void LayoutTreeBuilderForElement::createLayoutObject()
LayoutObject* nextRenderer = this->nextRenderer();
m_node->setLayoutObject(newLayoutObject);
- newLayoutObject->setStyle(&style); // setStyle() can depend on renderer() already being set.
+ newLayoutObject->setStyle(&style); // setStyle() can depend on layoutObject() already being set.
if (Fullscreen::isActiveFullScreenElement(*m_node)) {
newLayoutObject = LayoutFullScreen::wrapRenderer(newLayoutObject, parentRenderer, &m_node->document());
@@ -142,7 +142,7 @@ void LayoutTreeBuilderForElement::createLayoutObject()
return;
}
// Note: Adding newLayoutObject instead of renderer(). renderer() may be a child of newLayoutObject.
parentRenderer->addChild(newLayoutObject, nextRenderer);
}
« no previous file with comments | « Source/core/dom/LayoutTreeBuilder.h ('k') | Source/core/dom/Node.h » ('j') | no next file with comments »
@@ -142,7 +142,7 @@ void LayoutTreeBuilderForElement::createLayoutObject()
return;
}
- // Note: Adding newLayoutObject instead of renderer(). renderer() may be a child of newLayoutObject.
+ // Note: Adding newLayoutObject instead of layoutObject(). layoutObject() may be a child of newLayoutObject.
parentRenderer->addChild(newLayoutObject, nextRenderer);
}

Powered by Google App Engine
This is Rietveld 408576698